@@ -78,6 +78,23 @@ class _Pool:
         pool = {"url": self.url, "user": username, "pass": self.password}
         return pool
 
+    def as_inno(self, user_suffix: str = None) -> dict:
+        """Convert the data in this class to a dict usable by an Innosilicon device.
+
+        Parameters:
+             user_suffix: The suffix to append to username.
+        """
+        username = self.username
+        if user_suffix:
+            username = f"{username}{user_suffix}"
+
+        pool = {
+            f"Pool": self.url,
+            f"UserName": username,
+            f"Password": self.password,
+        }
+        return pool
+
     def as_avalon(self, user_suffix: str = None) -> str:
         """Convert the data in this class to a string usable by an Avalonminer device.
 
@@ -154,6 +171,19 @@ class _PoolGroup:
             pools.append(pool.as_x19(user_suffix=user_suffix))
         return pools
 
+    def as_inno(self, user_suffix: str = None) -> dict:
+        """Convert the data in this class to a list usable by an Innosilicon device.
+
+        Parameters:
+             user_suffix: The suffix to append to username.
+        """
+        pools = {}
+        for idx, pool in enumerate(self.pools[:3]):
+            pool_data = pool.as_inno(user_suffix=user_suffix)
+            for key in pool_data:
+                pools[f"{key}{idx+1}"] = pool_data[key]
+        return pools
+
     def as_wm(self, user_suffix: str = None) -> List[dict]:
         """Convert the data in this class to a list usable by an Whatsminer device.
 
@@ -217,7 +247,7 @@ class MinerConfig:
     temp_mode: Literal["auto", "manual", "disabled"] = "auto"
     temp_target: float = 70.0
     temp_hot: float = 80.0
-    temp_dangerous: float = 10.0
+    temp_dangerous: float = 100.0
 
     minimum_fans: int = None
     fan_speed: Literal[tuple(range(101))] = None  # noqa - Ignore weird Literal usage
@@ -269,6 +299,10 @@ class MinerConfig:
                     self.temp_mode = "manual"
                     if data.get("bitmain-fan-pwm"):
                         self.fan_speed = int(data["bitmain-fan-pwm"])
+            elif key == "bitmain-work-mode":
+                if data[key]:
+                    if data[key] == 1:
+                        self.autotuning_wattage = 0
             elif key == "fan_control":
                 for _key in data[key].keys():
                     if _key == "min_fans":
@@ -359,7 +393,15 @@ class MinerConfig:
         Parameters:
             user_suffix: The suffix to append to username.
         """
-        return self.pool_groups[0].as_x19(user_suffix=user_suffix)
+        return self.pool_groups[0].as_wm(user_suffix=user_suffix)
+
+    def as_inno(self, user_suffix: str = None) -> dict:
+        """Convert the data in this class to a config usable by an Innosilicon device.
+
+        Parameters:
+            user_suffix: The suffix to append to username.
+        """
+        return self.pool_groups[0].as_inno(user_suffix=user_suffix)
 
     def as_x19(self, user_suffix: str = None) -> str:
         """Convert the data in this class to a config usable by an X19 device.
@@ -371,7 +413,10 @@ class MinerConfig:
             "pools": self.pool_groups[0].as_x19(user_suffix=user_suffix),
             "bitmain-fan-ctrl": False,
             "bitmain-fan-pwn": 100,
+            "miner-mode": 0,  # Normal Mode
         }
+        if self.autotuning_wattage == 0:
+            cfg["miner-mode"] = 1  # Sleep Mode
 
         if not self.temp_mode == "auto":
             cfg["bitmain-fan-ctrl"] = True
