@@ -17,8 +17,9 @@ from dataclasses import dataclass, field, asdict
 from datetime import datetime, timezone
 import time
 import json
+import copy
 
-from .error_codes import X19Error, WhatsminerError, BraiinsOSError
+from .error_codes import X19Error, WhatsminerError, BraiinsOSError, InnosiliconError
 
 
 @dataclass
@@ -54,7 +55,7 @@ class MinerData:
         total_chips: The total number of chips on all boards.  Calculated automatically.
         ideal_chips: The ideal number of chips in the miner as an int.
         percent_ideal: The percent of total chips out of the ideal count.  Calculated automatically.
-        nominal: The nominal amount of chips in the miner.  Calculated automatically.
+        nominal: Whether the number of chips in the miner is nominal.  Calculated automatically.
         pool_split: The pool split as a str.
         pool_1_url: The first pool url on the miner as a str.
         pool_1_user: The first pool user on the miner as a str.
@@ -100,9 +101,9 @@ class MinerData:
     pool_1_user: str = "Unknown"
     pool_2_url: str = ""
     pool_2_user: str = ""
-    errors: List[Union[WhatsminerError, BraiinsOSError, X19Error]] = field(
-        default_factory=list
-    )
+    errors: List[
+        Union[WhatsminerError, BraiinsOSError, X19Error, InnosiliconError]
+    ] = field(default_factory=list)
     fault_light: Union[bool, None] = None
     efficiency: int = field(init=False)
 
@@ -121,6 +122,43 @@ class MinerData:
     def __iter__(self):
         return iter([item for item in self.asdict()])
 
+    def __truediv__(self, other):
+        return self // other
+
+    def __floordiv__(self, other):
+        cp = copy.deepcopy(self)
+        for key in self:
+            item = getattr(self, key)
+            if isinstance(item, int):
+                setattr(cp, key, item // other)
+            if isinstance(item, float):
+                setattr(cp, key, round(item / other, 2))
+        return cp
+
+    def __add__(self, other):
+        if not isinstance(other, MinerData):
+            raise TypeError("Cannot add MinerData to non MinerData type.")
+        cp = copy.deepcopy(self)
+        for key in self:
+            item = getattr(self, key)
+            other_item = getattr(other, key)
+            if item is None:
+                item = 0
+            if other_item is None:
+                other_item = 0
+
+            if isinstance(item, int):
+                setattr(cp, key, item + other_item)
+            if isinstance(item, float):
+                setattr(cp, key, item + other_item)
+            if isinstance(item, str):
+                setattr(cp, key, "")
+            if isinstance(item, list):
+                setattr(cp, key, item + other_item)
+            if isinstance(item, bool):
+                setattr(cp, key, item & other_item)
+        return cp
+
     @property
     def total_chips(self):  # noqa - Skip PyCharm inspection
         return self.right_chips + self.center_chips + self.left_chips
@@ -175,15 +213,39 @@ class MinerData:
     def efficiency(self, val):
         pass
 
-    def asdict(self):
+    def asdict(self) -> dict:
+        """Get this dataclass as a dictionary.
+
+        Returns:
+            A dictionary version of this class.
+        """
         return asdict(self)
 
-    def as_json(self):
+    def as_json(self) -> str:
+        """Get this dataclass as JSON.
+
+        Returns:
+            A JSON version of this class.
+        """
         data = self.asdict()
         data["datetime"] = str(int(time.mktime(data["datetime"].timetuple())))
         return json.dumps(data)
 
-    def as_influxdb(self, measurement_name: str = "miner_data"):
+    def as_csv(self) -> str:
+        data = self.asdict()
+        data["datetime"] = str(int(time.mktime(data["datetime"].timetuple())))
+        data_list = [str(data[item]) for item in data]
+        return ", ".join(data_list)
+
+    def as_influxdb(self, measurement_name: str = "miner_data") -> str:
+        """Get this dataclass as [influxdb line protocol](https://docs.influxdata.com/influxdb/v2.4/reference/syntax/line-protocol/).
+
+        Parameters:
+            measurement_name: The name of the measurement to insert into in influxdb.
+
+        Returns:
+            A influxdb line protocol version of this class.
+        """
         tag_data = [measurement_name]
         field_data = []
 
@@ -208,6 +270,9 @@ class MinerData:
             if attribute == "fault_light" and not self[attribute]:
                 field_data.append(f"{attribute}=false")
                 continue
+            if attribute == "errors":
+                for idx, item in enumerate(self[attribute]):
+                    field_data.append(f'error_{idx+1}="{item.error_message}"')
 
         tags_str = ",".join(tag_data)
         field_str = ",".join(field_data)
