@@ -14,7 +14,7 @@
 
 import ipaddress
 import logging
-from typing import Union
+from typing import Union, List
 
 
 from pyasic.API.bmminer import BMMinerAPI
@@ -22,6 +22,7 @@ from pyasic.miners.base import BaseMiner
 
 from pyasic.data import MinerData
 from pyasic.config import MinerConfig
+from pyasic.data.error_codes import MinerErrorData
 
 from pyasic.settings import PyasicSettings
 
@@ -169,7 +170,7 @@ class BMMiner(BaseMiner):
     async def fault_light_on(self) -> bool:
         return False
 
-    async def get_errors(self) -> list:
+    async def get_errors(self) -> List[MinerErrorData]:
         return []
 
     async def get_mac(self) -> str:
@@ -178,6 +179,12 @@ class BMMiner(BaseMiner):
     async def restart_backend(self) -> bool:
         return False
 
+    async def stop_mining(self) -> bool:
+        return False
+
+    async def resume_mining(self) -> bool:
+        return False
+
     async def get_data(self) -> MinerData:
         """Get data from the miner.
 
@@ -249,15 +256,26 @@ class BMMiner(BaseMiner):
                     data.center_chips = boards[1].get(f"chain_acn{board_offset+1}")
                     data.right_chips = boards[1].get(f"chain_acn{board_offset+2}")
 
-                    data.left_board_hashrate = round(
-                        float(boards[1].get(f"chain_rate{board_offset}")) / 1000, 2
-                    )
-                    data.center_board_hashrate = round(
-                        float(boards[1].get(f"chain_rate{board_offset+1}")) / 1000, 2
-                    )
-                    data.right_board_hashrate = round(
-                        float(boards[1].get(f"chain_rate{board_offset+2}")) / 1000, 2
-                    )
+                    try:
+                        data.left_board_hashrate = round(
+                            float(boards[1].get(f"chain_rate{board_offset}")) / 1000, 2
+                        )
+                    except ValueError as e:
+                        data.left_board_hashrate = round(0.00, 2)
+                    try:
+                        data.center_board_hashrate = round(
+                            float(boards[1].get(f"chain_rate{board_offset+1}")) / 1000,
+                            2,
+                        )
+                    except ValueError as e:
+                        data.center_board_hashrate = round(0.00, 2)
+                    try:
+                        data.right_board_hashrate = round(
+                            float(boards[1].get(f"chain_rate{board_offset+2}")) / 1000,
+                            2,
+                        )
+                    except ValueError as e:
+                        data.right_board_hashrate = round(0.00, 2)
 
         if stats:
             temp = stats.get("STATS")
