@@ -15,16 +15,16 @@
 import ipaddress
 import logging
 import json
-from typing import Union
+from typing import Union, List
 
 import toml
 
 
 from pyasic.miners.base import BaseMiner
 from pyasic.API.bosminer import BOSMinerAPI
-from pyasic.API import APIError
+from pyasic.errors import APIError
 
-from pyasic.data.error_codes import BraiinsOSError
+from pyasic.data.error_codes import BraiinsOSError, MinerErrorData
 from pyasic.data import MinerData
 
 from pyasic.config import MinerConfig
@@ -103,6 +103,20 @@ class BOSMiner(BaseMiner):
             return True
         return False
 
+    async def stop_mining(self) -> bool:
+        data = await self.api.pause()
+        if data.get("PAUSE"):
+            if data["PAUSE"][0]:
+                return True
+        return False
+
+    async def resume_mining(self) -> bool:
+        data = await self.api.resume()
+        if data.get("RESUME"):
+            if data["RESUME"][0]:
+                return True
+        return False
+
     async def reboot(self) -> bool:
         """Reboots power to the physical miner."""
         logging.debug(f"{self}: Sending reboot command.")
@@ -232,11 +246,17 @@ class BOSMiner(BaseMiner):
             await conn.run("/etc/init.d/bosminer start")
 
     async def check_light(self) -> bool:
-        if not self.light:
-            self.light = False
+        if self.light:
+            return self.light
+        data = (
+            await self.send_ssh_command("cat /sys/class/leds/'Red LED'/delay_off")
+        ).strip()
+        self.light = False
+        if data == "50":
+            self.light = True
         return self.light
 
-    async def get_errors(self) -> list:
+    async def get_errors(self) -> List[MinerErrorData]:
         tunerstatus = None
         errors = []
 
@@ -267,7 +287,7 @@ class BOSMiner(BaseMiner):
                                 "Stable",
                                 "Testing performance profile",
                             ]:
-                                _error = board["Status"]
+                                _error = board["Status"].split(" {")[0]
                                 _error = _error[0].lower() + _error[1:]
                                 errors.append(
                                     BraiinsOSError(f"{board_map[_id]} {_error}")
@@ -431,7 +451,7 @@ class BOSMiner(BaseMiner):
                                 "Stable",
                                 "Testing performance profile",
                             ]:
-                                _error = board["Status"]
+                                _error = board["Status"].split(" {")[0]
                                 _error = _error[0].lower() + _error[1:]
                                 data.errors.append(
                                     BraiinsOSError(f"{board_map[_id]} {_error}")
