@@ -15,11 +15,13 @@
 import logging
 
 import ipaddress
-from typing import Union
+from typing import Union, List
 
 from pyasic.API.bosminer import BOSMinerAPI
 from pyasic.miners.base import BaseMiner
 from pyasic.config import MinerConfig
+from pyasic.data import MinerData
+from pyasic.data.error_codes import MinerErrorData
 
 
 class BOSMinerOld(BaseMiner):
@@ -76,7 +78,7 @@ class BOSMinerOld(BaseMiner):
     async def get_config(self) -> None:
         return None
 
-    async def get_errors(self) -> list:
+    async def get_errors(self) -> List[MinerErrorData]:
         return []
 
     async def get_hostname(self) -> str:
@@ -94,5 +96,14 @@ class BOSMinerOld(BaseMiner):
     async def restart_backend(self) -> bool:
         return False
 
+    async def stop_mining(self) -> bool:
+        return False
+
+    async def resume_mining(self) -> bool:
+        return False
+
     async def send_config(self, config: MinerConfig, user_suffix: str = None) -> None:
         return None
+
+    async def get_data(self) -> MinerData:
+        return MinerData(ip=str(self.ip))
