@@ -28,7 +28,7 @@ class M30SPlusPlusVG30(BaseMiner):
     def __init__(self, ip: str):
         super().__init__()
         self.ip = ip
-        self.model = "M30S++ V30"
+        self.model = "M30S++ VG30"
         self.nominal_chips = 111
         self.fan_count = 2
 
@@ -37,6 +37,15 @@ class M30SPlusPlusVG40(BaseMiner):
     def __init__(self, ip: str):
         super().__init__()
         self.ip = ip
-        self.model = "M30S++ V40"
+        self.model = "M30S++ VG40"
         self.nominal_chips = 117
         self.fan_count = 2
+
+
+class M30SPlusPlusVH60(BaseMiner):
+    def __init__(self, ip: str):
+        super().__init__()
+        self.ip = ip
+        self.model = "M30S++ VH60"
+        self.nominal_chips = 78
+        self.fan_count = 2
