@@ -14,10 +14,23 @@
 
 from .M30S import M30S, M30SVE10, M30SVE20, M30SVG20, M30SV50
 from .M30S_Plus import M30SPlus, M30SPlusVG60, M30SPlusVE40, M30SPlusVF20
-from .M30S_Plus_Plus import M30SPlusPlus, M30SPlusPlusVG30, M30SPlusPlusVG40
+from .M30S_Plus_Plus import (
+    M30SPlusPlus,
+    M30SPlusPlusVG30,
+    M30SPlusPlusVG40,
+    M30SPlusPlusVH60,
+)
 
 from .M31S import M31S
-from .M31S_Plus import M31SPlus, M31SPlusVE20
+from .M31S_Plus import (
+    M31SPlus,
+    M31SPlusVE20,
+    M31SPlusV30,
+    M31SPlusV40,
+    M31SPlusV80,
+    M31SPlusV60,
+    M31SPlusV90,
+)
 
 from .M32 import M32, M32V20
 from .M32S import M32S
