@@ -20,6 +20,7 @@ import httpx
 from pyasic.miners.antminer import *
 from pyasic.miners.avalonminer import *
 from pyasic.miners.whatsminer import *
+from pyasic.miners.innosilicon import *
 
 from pyasic.miners._backends.cgminer import CGMiner  # noqa - Ignore _module import
 from pyasic.miners._backends.bmminer import BMMiner  # noqa - Ignore _module import
@@ -31,7 +32,9 @@ from pyasic.miners._backends.bosminer_old import (  # noqa - Ignore _module impo
 
 from pyasic.miners.unknown import UnknownMiner
 
-from pyasic.API import APIError
+from pyasic.errors import APIError
+
+from pyasic.misc import Singleton
 
 import asyncio
 import ipaddress
@@ -58,6 +61,7 @@ MINER_CLASSES = {
         "Default": BMMinerT9,
         "BMMiner": BMMinerT9,
         "Hiveon": HiveonT9,
+        "CGMiner": CGMinerT9,
     },
     "ANTMINER S17": {
         "Default": BMMinerS17,
@@ -125,6 +129,10 @@ MINER_CLASSES = {
         "BMMiner": BMMinerS19jPro,
         "CGMiner": CGMinerS19jPro,
     },
+    "ANTMINER S19 XP": {
+        "Default": BMMinerS19XP,
+        "BMMiner": BMMinerS19XP,
+    },
     "ANTMINER S19A": {
         "Default": BMMinerS19a,
         "BMMiner": BMMinerS19a,
@@ -193,6 +201,11 @@ MINER_CLASSES = {
         "Default": BTMinerM31SPlus,
         "BTMiner": BTMinerM31SPlus,
         "E20": BTMinerM31SPlusVE20,
+        "30": BTMinerM31SPlusV30,
+        "40": BTMinerM31SPlusV40,
+        "60": BTMinerM31SPlusV60,
+        "80": BTMinerM31SPlusV80,
+        "90": BTMinerM31SPlusV90,
     },
     "M32S": {
         "Default": BTMinerM32S,
@@ -243,19 +256,14 @@ MINER_CLASSES = {
         "Default": CGMinerAvalon1066,
         "CGMiner": CGMinerAvalon1066,
     },
+    "T3H+": {
+        "Default": CGMinerInnosiliconT3HPlus,
+        "CGMiner": CGMinerInnosiliconT3HPlus,
+    },
     "Unknown": {"Default": UnknownMiner},
 }
 
 
-class Singleton(type):
-    _instances = {}
-
-    def __call__(cls, *args, **kwargs):
-        if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
-        return cls._instances[cls]
-
-
 class MinerFactory(metaclass=Singleton):
     """A factory to handle identification and selection of the proper class of miner"""
 
@@ -407,9 +415,13 @@ class MinerFactory(metaclass=Singleton):
             except asyncssh.misc.PermissionDenied:
                 try:
                     data = await self.__get_system_info_from_web(ip)
-                    if "minertype" in data.keys():
+                    if not data.get("success"):
+                        _model = await self.__get_dragonmint_version_from_web(ip)
+                        if _model:
+                            model = _model
+                    if "minertype" in data:
                         model = data["minertype"].upper()
-                    if "bmminer" in "\t".join(data.keys()):
+                    if "bmminer" in "\t".join(data):
                         api = "BMMiner"
                 except Exception as e:
                     logging.debug(f"Unable to get miner - {e}")
@@ -488,8 +500,16 @@ class MinerFactory(metaclass=Singleton):
                     if "PRO" in _model and " PRO" not in _model:
                         _model = _model.replace("PRO", " PRO")
                     model = _model
+            else:
+                _model = await self.__get_dragonmint_version_from_web(ip)
+                if _model:
+                    model = _model
 
         if model:
+            if "DRAGONMINT" in model:
+                _model = await self.__get_dragonmint_version_from_web(ip)
+                if _model:
+                    model = _model
             if " HIVEON" in model:
                 # do hiveon check before whatsminer as HIVEON contains a V
                 model = model.split(" HIVEON")[0]
@@ -573,6 +593,31 @@ class MinerFactory(metaclass=Singleton):
             data = data.json()
         return data
 
+    @staticmethod
+    async def __get_dragonmint_version_from_web(
+        ip: ipaddress.ip_address,
+    ) -> Union[str, None]:
+        response = None
+        async with httpx.AsyncClient() as client:
+            try:
+                auth = (
+                    await client.post(
+                        f"http://{ip}/api/auth",
+                        data={"username": "admin", "password": "admin"},
+                    )
+                ).json()["jwt"]
+                response = (
+                    await client.post(
+                        f"http://{ip}/api/type",
+                        headers={"Authorization": "Bearer " + auth},
+                        data={},
+                    )
+                ).json()
+            except Exception as e:
+                logging.info(e)
+        if response:
+            return response["type"]
+
     @staticmethod
     async def _validate_command(data: dict) -> Tuple[bool, Union[str, None]]:
         """Check if the returned command output is correctly formatted."""
@@ -595,9 +640,7 @@ class MinerFactory(metaclass=Singleton):
         else:
             # make sure the command succeeded
             if data["STATUS"][0]["STATUS"] not in ("S", "I"):
-                # this is an error
-                if data["STATUS"][0]["STATUS"] not in ("S", "I"):
-                    return False, data["STATUS"][0]["Msg"]
+                return False, data["STATUS"][0]["Msg"]
         return True, None
 
     @staticmethod
