@@ -14,14 +14,7 @@
 
 import asyncio
 
-
-class Singleton(type):
-    _instances = {}
-
-    def __call__(cls, *args, **kwargs):
-        if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
-        return cls._instances[cls]
+from pyasic.misc import Singleton
 
 
 class _MinerListener:
