@@ -17,6 +17,7 @@ from pyasic.miners._types import (  # noqa - Ignore access to _module
     M30SPlusPlus,
     M30SPlusPlusVG40,
     M30SPlusPlusVG30,
+    M30SPlusPlusVH60,
 )
 
 
@@ -36,3 +37,9 @@ class BTMinerM30SPlusPlusVG40(BTMiner, M30SPlusPlusVG40):
     def __init__(self, ip: str) -> None:
         super().__init__(ip)
         self.ip = ip
+
+
+class BTMinerM30SPlusPlusVH60(BTMiner, M30SPlusPlusVH60):
+    def __init__(self, ip: str) -> None:
+        super().__init__(ip)
+        self.ip = ip
