@@ -29,10 +29,19 @@ from .M30S_Plus_Plus import (
     BTMinerM30SPlusPlus,
     BTMinerM30SPlusPlusVG40,
     BTMinerM30SPlusPlusVG30,
+    BTMinerM30SPlusPlusVH60,
 )
 
 from .M31S import BTMinerM31S
-from .M31S_Plus import BTMinerM31SPlus, BTMinerM31SPlusVE20
+from .M31S_Plus import (
+    BTMinerM31SPlus,
+    BTMinerM31SPlusVE20,
+    BTMinerM31SPlusV30,
+    BTMinerM31SPlusV40,
+    BTMinerM31SPlusV60,
+    BTMinerM31SPlusV80,
+    BTMinerM31SPlusV90,
+)
 
 from .M32 import BTMinerM32, BTMinerM32V20
 from .M32S import BTMinerM32S
