@@ -37,7 +37,9 @@ class MinerNetwork:
     """
 
     def __init__(
-        self, ip_addr: Union[str, None] = None, mask: Union[str, int, None] = None
+        self,
+        ip_addr: Union[str, List[str], None] = None,
+        mask: Union[str, int, None] = None,
     ) -> None:
         self.network = None
         self.ip_addr = ip_addr
@@ -46,6 +48,7 @@ class MinerNetwork:
             if mask.startswith("/"):
                 mask = mask.replace("/", "")
         self.mask = mask
+        self.network = self.get_network()
 
     def __len__(self):
         return len([item for item in self.get_network().hosts()])
@@ -53,6 +56,10 @@ class MinerNetwork:
     def __repr__(self):
         return str(self.network)
 
+    def hosts(self):
+        for x in self.network.hosts():
+            yield x
+
     def get_network(self) -> ipaddress.ip_network:
         """Get the network using the information passed to the MinerNetwork or from cache.
 
@@ -63,18 +70,14 @@ class MinerNetwork:
         if self.network:
             return self.network
 
+            # if there is no IP address passed, default to 192.168.1.0
+        if not self.ip_addr:
+            self.ip_addr = "192.168.1.0"
         if "-" in self.ip_addr:
             self.network = MinerNetworkRange(self.ip_addr)
         elif isinstance(self.ip_addr, list):
             self.network = MinerNetworkRange(self.ip_addr)
         else:
-            # if there is no IP address passed, default to 192.168.1.0
-            if not self.ip_addr:
-                default_gateway = "192.168.1.0"
-            # if we do have an IP address passed, use that
-            else:
-                default_gateway = self.ip_addr
-
             # if there is no subnet mask passed, default to /24
             if not self.mask:
                 subnet_mask = "24"
@@ -84,7 +87,7 @@ class MinerNetwork:
 
             # save the network and return it
             self.network = ipaddress.ip_network(
-                f"{default_gateway}/{subnet_mask}", strict=False
+                f"{self.ip_addr}/{subnet_mask}", strict=False
             )
 
         logging.debug(f"Setting MinerNetwork: {self.network}")
