@@ -14,14 +14,7 @@
 
 from dataclasses import dataclass
 
-
-class Singleton(type):
-    _instances = {}
-
-    def __call__(cls, *args, **kwargs):
-        if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
-        return cls._instances[cls]
+from pyasic.misc import Singleton
 
 
 @dataclass
@@ -35,6 +28,7 @@ class PyasicSettings(metaclass=Singleton):
     miner_get_data_retries: int = 1
 
     global_whatsminer_password = "admin"
+    global_innosilicon_password = "admin"
     global_x19_password = "root"
     global_x17_password = "root"
 
